<?php
/**
 * Main Slider Customizer options
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */


// Add Main Slider enable section
$wp_customize->add_section( 'daily_insight_pro_main_slider_section', array(
	'title'             => esc_html__( 'Main Slider','daily-insight-pro' ),
	'description'       => esc_html__( 'Main Slider section options.', 'daily-insight-pro' ),
	'priority'			=> '10',
	'panel'             => 'daily_insight_pro_sections_panel'
) );

// Add Main Slider enable setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[enable_main_slider]', array(
	'default'           => $options['enable_main_slider'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_select'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[enable_main_slider]', array(
	'label'             => esc_html__( 'Enable On', 'daily-insight-pro' ),
	'section'           => 'daily_insight_pro_main_slider_section',
	'type'              => 'select',
	'choices'			=> daily_insight_pro_enable_disable_options(),
) );

// Add Main Slider content type setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[main_slider_type]', array(
	'default'           => $options['main_slider_type'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_select'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[main_slider_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_main_slider_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'daily_insight_pro_is_main_slider_active',
	'choices'         	=> array(
		'demo'			=> esc_html__( 'Demo','daily-insight-pro'),
		'category'		=> esc_html__( 'Category', 'daily-insight-pro' ),
		'post'			=> esc_html__( 'Post', 'daily-insight-pro' ),
		'page'			=> esc_html__( 'Page', 'daily-insight-pro')	
	)
) );

// Add slider effects setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[slider_content_effect]', array(
	'default'           => $options['slider_content_effect'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_select'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[slider_content_effect]', array(
	'label'           => esc_html__( 'Transition Effects', 'daily-insight-pro' ),
	'section'         => 'daily_insight_pro_main_slider_section',
	'type'            => 'select',
	'active_callback' => 'daily_insight_pro_is_main_slider_demo_not_active',
	'choices'         => daily_insight_pro_slider_effect(),
) );

// Add enable arrow controls setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[enable_slider_controls]', array(
	'default'           => $options['enable_slider_controls'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[enable_slider_controls]', array(
	'label'           => esc_html__( 'Enable Arrow Controls', 'daily-insight-pro' ),
	'section'         => 'daily_insight_pro_main_slider_section',
	'type'            => 'checkbox',
	'active_callback' => 'daily_insight_pro_is_main_slider_demo_not_active',
) );

// Add enable slider dragable setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[enable_slider_dragable]', array(
	'default'           => $options['enable_slider_dragable'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[enable_slider_dragable]', array(
	'label'           => esc_html__( 'Slider Dragable', 'daily-insight-pro' ),
	'section'         => 'daily_insight_pro_main_slider_section',
	'type'            => 'checkbox',
	'active_callback' => 'daily_insight_pro_is_main_slider_demo_not_active',
) );

// Add enable slider pause on hover setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[slider_pause_on_hover]', array(
	'default'           => $options['slider_pause_on_hover'],
	'sanitize_callback' => 'daily_insight_pro_sanitize_checkbox'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[slider_pause_on_hover]', array(
	'label'           => esc_html__( 'Pause On Hover', 'daily-insight-pro' ),
	'section'         => 'daily_insight_pro_main_slider_section',
	'type'            => 'checkbox',
	'active_callback' => 'daily_insight_pro_is_main_slider_demo_not_active',
) );
// Add Main Slider number of posts setting and control.
$wp_customize->add_setting( 'daily_insight_pro_theme_options[main_slider_no_of_posts]', array(
	'default'           => $options['main_slider_no_of_posts'],
	'validate_callback' => 'daily_insight_pro_validate_no_of_main_slider',
	'sanitize_callback' => 'daily_insight_pro_sanitize_number_range'
) );

$wp_customize->add_control( 'daily_insight_pro_theme_options[main_slider_no_of_posts]', array(
	'label'           	=> esc_html__( 'Number Of Main Slider', 'daily-insight-pro' ),
	'description'       => esc_html__( 'Notice: Please refresh after the number of slides is set to see the effects.', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_main_slider_section',
	'type'            	=> 'number',
	'active_callback' 	=> 'daily_insight_pro_is_main_slider_demo_not_active',
	'input_attrs'		=> array(
		'min'			=> '2',
		'max'			=> '5',
		'step'			=> '1',
		'style'			=> 'width:50px',
		),
) );

// Add Main Slider category drop-down setting and control
$wp_customize->add_setting( 'daily_insight_pro_theme_options[main_slider_category_type]', array(
	'default'			=> $options['main_slider_category_type'],			
	'sanitize_callback'	=> 'daily_insight_pro_sanitize_category_list',
) );

$wp_customize->add_control( new Daily_Insight_Pro_Dropdown_Category_Control( $wp_customize, 'daily_insight_pro_theme_options[main_slider_category_type]', array(
	'active_callback' 	=> 'daily_insight_pro_is_main_slider_content_as_category',
	'label'           	=> esc_html__('Select Category', 'daily-insight-pro' ),
	'section'         	=> 'daily_insight_pro_main_slider_section',
	'type'            	=> 'dropdown-category',
 ) ) );


$value = daily_insight_pro_get_theme_options();
$no_of_post = $value['main_slider_no_of_posts'];

for ( $i = 1; $i <= $no_of_post; $i++ ) {
	// Insert main slider  post id
	$wp_customize->add_setting( 'daily_insight_pro_theme_options[post_id_' . $i . ']', array(
		'sanitize_callback' => 'daily_insight_pro_sanitize_number_range'
	) );

	$wp_customize->add_control( 'daily_insight_pro_theme_options[post_id_' . $i . ']', array(
		'label'             => esc_html__( 'Post id # ' , 'daily-insight-pro' ) . $i,
		'section'           => 'daily_insight_pro_main_slider_section',
		'input_attrs' 		=> array( 
			'style' 		=> 'width: 100px;',
			'min'			=> '1', 
			'placeholder'	=> esc_attr__( 'Post ID', 'daily-insight-pro' ) ),
		'type'              => 'number',
		'active_callback'	=> 'daily_insight_pro_is_main_slider_content_as_post'
	) );

	// Select main slider page
	$wp_customize->add_setting( 'daily_insight_pro_theme_options[page_id_' . $i . ']', array(
		'sanitize_callback' => 'daily_insight_pro_sanitize_page'
	) );

	$wp_customize->add_control( 'daily_insight_pro_theme_options[page_id_' . $i . ']', array(
		'label'             => esc_html__( 'Select Page # ' , 'daily-insight-pro' ) . $i,
		'section'           => 'daily_insight_pro_main_slider_section',
		'active_callback'	=> 'daily_insight_pro_is_main_slider_content_as_page',
		'type'              => 'dropdown-pages',
	) );
}


